@@ -109,13 +109,11 @@ if settings.DEBUG:
 
 script_templates = {
     'wsgi': '''
-#!/usr/bin/env python
+#!%(executable)s
 import os, sys
  
 # Add the project to the python path
-sys.path.extend(
-  %(extra_paths)s
-)
+sys.path[0:0] = %(extra_paths)s
  
 # Set our settings module
 os.environ['DJANGO_SETTINGS_MODULE'] = '%(project)s.%(settings)s'
@@ -128,13 +126,11 @@ import django.core.handlers.wsgi
 application = django.core.handlers.wsgi.WSGIHandler()
 ''',
     'fcgi': '''
-#!/usr/bin/env python
+#!%(executable)s
 import os, sys
 
 # Add the project to the python path
-sys.path.extend(
-  %(extra_paths)s
-)
+sys.path[0:0] = %(extra_paths)s
 
 # Set our settings module
 os.environ['DJANGO_SETTINGS_MODULE'] = '%(project)s.%(settings)s'
@@ -397,7 +393,7 @@ class Recipe(object):
 
 
     def make_script(self, protocol, extra_paths):
-        template = script_templates[protocol]
+        template = script_templates[protocol].strip()
         script_name = os.path.join(
             self.buildout['buildout']['bin-directory'],
             self.options.get('control-script', self.name) + '.%s' % protocol)
